/*****************************************************************************
 * © 2014 Avaya Inc. All rights reserved.
 ****************************************************************************/
package com.avaya.services.Callingpolicies;

import java.util.UUID;
import com.avaya.collaboration.call.Call;
import com.avaya.collaboration.call.media.DigitCollectorOperationCause;
import com.avaya.collaboration.call.media.MediaListenerAbstract;
import com.avaya.collaboration.util.logger.Logger;

public final class CallingPoliciesMediaListener extends MediaListenerAbstract
{
    private final Call call;
    private final ForkingOperation forkOperation;
    private final ServiceAttributeReader serviceAttributeReader;

    private final Logger logger;

    public CallingPoliciesMediaListener(final Call call)
    {
        this(call, new ForkingOperationImpl(), new ServiceAttributeReaderImpl(), Logger
                .getLogger(CallingPoliciesMediaListener.class));
    }

    CallingPoliciesMediaListener(final Call call, final ForkingOperation forkOperation,
            final ServiceAttributeReader serviceAttributeReader, final Logger logger)
    {
        this.call = call;
        this.forkOperation = forkOperation;
        this.serviceAttributeReader = serviceAttributeReader;

        this.logger = logger;
    }

    @Override
    public void digitsCollected(final UUID requestId, final String digits,
            final DigitCollectorOperationCause cause)
    {
        if (logger.isFinestEnabled())
        {
            logger.finest("digitsCollected: digit=" + digits);
        }

        if (!validateDigit(digits))
        {
            call.drop();
            return;
        }

        try
        {
            switch (digits)
            {
                case "1":
                    call.allow();
                    forkOperation.forkTo(call);
                    break;
                case "2":
                    final String redirectNumber =
                            serviceAttributeReader.getRedirectNumber(call.getCalledParty());
                    if (logger.isFinestEnabled())
                    {
                        logger.finest("digitsCollected: attempting to redirect to=" + redirectNumber);
                    }
                    call.divertTo(redirectNumber);
                    break;
                case "3":
                    call.allow();
                    break;
                case "4":
                    call.drop();
                    break;
                default:
                    logger.warn("digitsCollected: invalid digit=" + digits);
                    call.drop();
                    break;
            }
        }
        catch (final Exception e)
        {
            logger.error("digitsCollected: failed operation exception=", e);
            call.drop();
        }
    }

    private boolean validateDigit(final String collectedDigit)
    {
        try
        {
            final int digitCollected = Integer.parseInt(collectedDigit);
            return (digitCollected >= 1 || digitCollected <= 4);
        }
        catch (final Exception e)
        {
            logger.warn("checkDigitRange: invalid digit exception=" + e);
            return false;
        }
    }
}
